pub struct Path {
commands: Box<[PackedCommand]>,
coords: Box<[f64]>,
}Expand description
An immutable path with a compact representation.
This is constructed from a PathBuilder once it is finished. You
can get an iterator for the path’s commands with the iter
method, or an iterator for its subpaths (subsequences of commands that
start with a MoveTo) with the iter_subpath method.
The variants in PathCommand have different sizes, so a simple array of PathCommand
would have a lot of slack space. We reduce this to a minimum by separating the
commands from their coordinates. Then, we can have two dense arrays: one with a compact
representation of commands, and another with a linear list of the coordinates for each
command.
Both PathCommand and PackedCommand know how many coordinates they ought to
produce, with their num_coordinates methods.
This struct implements Default, and it yields an empty path.
Fields
commands: Box<[PackedCommand]>coords: Box<[f64]>Implementations
Sourceimpl Path
impl Path
pub fn to_cairo_path( &self, is_square_linecap: bool, ) -> Result<CairoPath, Box<InternalRenderingError>>
pub fn to_cairo( &self, cr: &Context, is_square_linecap: bool, ) -> Result<(), Box<InternalRenderingError>>
Sourceimpl Path
impl Path
Sourcepub fn iter_subpath(&self) -> SubPathIter<'_> ⓘ
pub fn iter_subpath(&self) -> SubPathIter<'_> ⓘ
Get an iterator over a path Subpaths.
Sourcepub fn iter(&self) -> impl Iterator<Item = PathCommand> + '_
pub fn iter(&self) -> impl Iterator<Item = PathCommand> + '_
Get an iterator over a path’s commands.